/soc/2013/ankitkv/gobjectification: 9b0109ae118d: Renamed some p...
Ankit Vani
a at nevitus.org
Sun Sep 1 06:39:18 EDT 2013
Changeset: 9b0109ae118da68f1c3fb97184629ae93b270ea5
Author: Ankit Vani <a at nevitus.org>
Date: 2013-09-01 14:24 +0530
Branch: soc.2013.gobjectification.plugins
URL: https://hg.pidgin.im/soc/2013/ankitkv/gobjectification/rev/9b0109ae118d
Description:
Renamed some prpl stuff to protocol stuff.
Renamed /plugins/prpl prefs to /protocols
diffstat:
finch/finch.c | 8 +-
finch/gntaccount.c | 24 +++++-----
finch/gntconv.c | 2 +-
libpurple/account.h | 8 +-
libpurple/accounts.c | 10 ++--
libpurple/blistnodetypes.c | 8 +-
libpurple/blistnodetypes.h | 6 +-
libpurple/buddyicon.h | 8 +-
libpurple/cmds.h | 6 +-
libpurple/connection.c | 6 +-
libpurple/connection.h | 6 +-
libpurple/conversationtypes.c | 8 +-
libpurple/example/nullclient.c | 8 +-
libpurple/ft.c | 16 +++---
libpurple/ft.h | 18 ++++----
libpurple/log.c | 16 +++---
libpurple/media.c | 8 +-
libpurple/media.h | 10 ++--
libpurple/media/backend-fs2.c | 2 +-
libpurple/network.h | 2 +-
libpurple/plugins/idle.c | 8 +-
libpurple/plugins/log_reader.c | 6 +-
libpurple/plugins/one_time_password.c | 12 +---
libpurple/plugins/signals-test.c | 6 +-
libpurple/prefs.c | 2 +-
libpurple/protocol.c | 4 +-
libpurple/protocol.h | 6 +-
libpurple/protocols.c | 4 +-
libpurple/protocols/bonjour/bonjour.h | 2 +-
libpurple/protocols/gg/gg.c | 2 +-
libpurple/protocols/gg/gg.h | 2 +-
libpurple/protocols/gg/image.c | 2 +-
libpurple/protocols/gg/servconn.c | 2 +-
libpurple/protocols/irc/irc.c | 4 +-
libpurple/protocols/irc/irc.h | 2 +-
libpurple/protocols/irc/parse.c | 4 +-
libpurple/protocols/jabber/caps.c | 2 +-
libpurple/protocols/jabber/chat.h | 4 +-
libpurple/protocols/jabber/iq.c | 2 +-
libpurple/protocols/jabber/jabber.c | 34 +++++++-------
libpurple/protocols/jabber/jabber.h | 4 +-
libpurple/protocols/jabber/libfacebook.c | 6 +-
libpurple/protocols/jabber/libfacebook.h | 2 +-
libpurple/protocols/jabber/libgtalk.c | 6 +-
libpurple/protocols/jabber/libgtalk.h | 2 +-
libpurple/protocols/jabber/libxmpp.c | 8 +-
libpurple/protocols/jabber/useravatar.c | 2 +-
libpurple/protocols/msn/msn.c | 16 +++---
libpurple/protocols/msn/msn.h | 2 +-
libpurple/protocols/mxit/mxit.h | 2 +-
libpurple/protocols/myspace/myspace.c | 4 +-
libpurple/protocols/myspace/myspace.h | 2 +-
libpurple/protocols/myspace/user.c | 2 +-
libpurple/protocols/novell/novell.c | 2 +-
libpurple/protocols/novell/novell.h | 2 +-
libpurple/protocols/null/nullprotocol.c | 4 +-
libpurple/protocols/null/nullprotocol.h | 2 +-
libpurple/protocols/oscar/clientlogin.c | 4 +-
libpurple/protocols/oscar/family_auth.c | 4 +-
libpurple/protocols/oscar/libicq.h | 2 +-
libpurple/protocols/oscar/oft.c | 2 +-
libpurple/protocols/oscar/oscar.c | 35 +++++++--------
libpurple/protocols/oscar/oscar.h | 2 +-
libpurple/protocols/oscar/oscarcommon.h | 2 +-
libpurple/protocols/sametime/sametime.c | 14 +++---
libpurple/protocols/silc/silc.c | 60 +++++++++++++-------------
libpurple/protocols/silc/silcpurple.h | 2 +-
libpurple/protocols/simple/simple.h | 2 +-
libpurple/protocols/yahoo/libyahoo.c | 18 ++++----
libpurple/protocols/yahoo/libyahoo.h | 2 +-
libpurple/protocols/yahoo/libyahoojp.c | 8 +-
libpurple/protocols/yahoo/libyahoojp.h | 2 +-
libpurple/protocols/yahoo/libymsg.c | 2 +-
libpurple/protocols/yahoo/libymsg.h | 2 +-
libpurple/protocols/yahoo/yahoo_packet.c | 2 +-
libpurple/protocols/yahoo/yahoo_profile.c | 2 +-
libpurple/protocols/zephyr/zephyr.c | 24 +++++-----
libpurple/protocols/zephyr/zephyr.h | 2 +-
libpurple/proxy.h | 4 +-
libpurple/request.h | 4 +-
libpurple/roomlist.c | 4 +-
libpurple/roomlist.h | 10 ++--
libpurple/savedstatuses.c | 4 +-
libpurple/server.c | 6 +-
libpurple/server.h | 20 ++++----
libpurple/status.h | 10 ++--
libpurple/util.c | 2 +-
libpurple/util.h | 8 +-
libpurple/whiteboard.c | 16 +++---
libpurple/whiteboard.h | 16 +++---
pidgin/gtkblist.c | 14 +++---
pidgin/gtkconv.c | 10 ++--
pidgin/gtkft.c | 4 +-
pidgin/gtkmain.c | 8 +-
pidgin/gtkstatusbox.c | 8 +-
pidgin/gtkutils.c | 6 +-
pidgin/gtkutils.h | 6 +-
pidgin/gtkwebviewtoolbar.c | 2 +-
pidgin/gtkwhiteboard.c | 2 +-
pidgin/gtkwhiteboard.h | 2 +-
pidgin/plugins/disco/xmppdisco.c | 14 +++---
pidgin/plugins/disco/xmppdisco.h | 2 +-
pidgin/plugins/gevolution/add_buddy_dialog.c | 28 ++++++------
pidgin/plugins/gevolution/gevo-util.c | 18 ++++----
pidgin/plugins/gevolution/gevolution.c | 14 +++---
pidgin/plugins/gevolution/new_person_dialog.c | 14 +++---
pidgin/plugins/raw.c | 8 +-
pidgin/plugins/xmppconsole.c | 6 +-
108 files changed, 406 insertions(+), 415 deletions(-)
diffs (truncated from 3218 to 300 lines):
diff --git a/finch/finch.c b/finch/finch.c
--- a/finch/finch.c
+++ b/finch/finch.c
@@ -79,7 +79,7 @@ static GHashTable *finch_ui_get_info(voi
* possible it has been re-added). AOL's old key management
* page is http://developer.aim.com/manageKeys.jsp
*/
- g_hash_table_insert(ui_info, "prpl-aim-clientkey", "ma19sqWV9ymU6UYc");
+ g_hash_table_insert(ui_info, "protocol-aim-clientkey", "ma19sqWV9ymU6UYc");
/*
* This is the client key for "Pidgin." It is owned by the AIM
@@ -95,15 +95,15 @@ static GHashTable *finch_ui_get_info(voi
* (ma19sqWV9ymU6UYc), but it stopped working, so we switched
* to this one.
*/
- g_hash_table_insert(ui_info, "prpl-icq-clientkey", "ma1cSASNCKFtrdv9");
+ g_hash_table_insert(ui_info, "protocol-icq-clientkey", "ma1cSASNCKFtrdv9");
/*
* This is the distid for Finch, given to us by AOL. Please
* don't use this for other applications. You can just not
* specify a distid and libpurple will use a default.
*/
- g_hash_table_insert(ui_info, "prpl-aim-distid", GINT_TO_POINTER(1552));
- g_hash_table_insert(ui_info, "prpl-icq-distid", GINT_TO_POINTER(1552));
+ g_hash_table_insert(ui_info, "protocol-aim-distid", GINT_TO_POINTER(1552));
+ g_hash_table_insert(ui_info, "protocol-icq-distid", GINT_TO_POINTER(1552));
}
return ui_info;
diff --git a/finch/gntaccount.c b/finch/gntaccount.c
--- a/finch/gntaccount.c
+++ b/finch/gntaccount.c
@@ -75,7 +75,7 @@ typedef struct
GList *split_entries;
GList *protocol_entries;
- GntWidget *prpls;
+ GntWidget *protocols;
GntWidget *newmail;
GntWidget *remember;
@@ -164,21 +164,21 @@ save_account_cb(AccountEditDialog *dialo
purple_account_set_username(account, username->str);
} else {
const char *old = purple_account_get_protocol_id(account);
- char *oldprpl;
+ char *oldproto;
if (strcmp(old, purple_protocol_get_id(protocol))) {
purple_notify_error(NULL, _("Error"), _("Account was not modified"),
_("The account's protocol cannot be changed while it is connected to the server."));
return;
}
- oldprpl = g_strdup(purple_normalize(account, purple_account_get_username(account)));
- if (g_utf8_collate(oldprpl, purple_normalize(account, username->str))) {
+ oldproto = g_strdup(purple_normalize(account, purple_account_get_username(account)));
+ if (g_utf8_collate(oldproto, purple_normalize(account, username->str))) {
purple_notify_error(NULL, _("Error"), _("Account was not modified"),
_("The account's username cannot be changed while it is connected to the server."));
- g_free(oldprpl);
+ g_free(oldproto);
return;
}
- g_free(oldprpl);
+ g_free(oldproto);
purple_account_set_username(account, username->str);
}
}
@@ -369,11 +369,11 @@ add_protocol_options(AccountEditDialog *
GntWidget *vbox, *box;
PurpleAccount *account;
- if (dialog->prpls)
- gnt_box_remove_all(GNT_BOX(dialog->prpls));
+ if (dialog->protocols)
+ gnt_box_remove_all(GNT_BOX(dialog->protocols));
else
{
- dialog->prpls = vbox = gnt_vbox_new(FALSE);
+ dialog->protocols = vbox = gnt_vbox_new(FALSE);
gnt_box_set_pad(GNT_BOX(vbox), 0);
gnt_box_set_alignment(GNT_BOX(vbox), GNT_ALIGN_LEFT);
gnt_box_set_fill(GNT_BOX(vbox), TRUE);
@@ -385,7 +385,7 @@ add_protocol_options(AccountEditDialog *
dialog->protocol_entries = NULL;
}
- vbox = dialog->prpls;
+ vbox = dialog->protocols;
protocol = gnt_combo_box_get_selected_data(GNT_COMBO_BOX(dialog->protocol));
if (!protocol)
@@ -482,7 +482,7 @@ add_protocol_options(AccountEditDialog *
}
/* Show the registration checkbox only in a new account dialog,
- * and when the selected prpl has the support for it. */
+ * and when the selected protocol has the support for it. */
gnt_widget_set_visible(dialog->regserver, account == NULL &&
PURPLE_PROTOCOL_IMPLEMENTS(protocol, register_user));
}
@@ -633,7 +633,7 @@ edit_account_continue(PurpleAccount *acc
/* The advanced box */
add_protocol_options(dialog);
- gnt_box_add_widget(GNT_BOX(window), dialog->prpls);
+ gnt_box_add_widget(GNT_BOX(window), dialog->protocols);
/* TODO: Add proxy options */
diff --git a/finch/gntconv.c b/finch/gntconv.c
--- a/finch/gntconv.c
+++ b/finch/gntconv.c
@@ -1244,7 +1244,7 @@ debug_command_cb(PurpleConversation *con
DISPLAY_VERSION, purple_core_get_version());
} else if (!g_ascii_strcasecmp(args[0], "plugins")) {
/* Show all the loaded plugins, including the protocol plugins and plugin loaders.
- * This is intentional, since third party prpls are often sources of bugs, and some
+ * This is intentional, since third party protocols are often sources of bugs, and some
* plugin loaders (e.g. mono) can also be buggy.
*/
GString *str = g_string_new("Loaded Plugins: ");
diff --git a/libpurple/account.h b/libpurple/account.h
--- a/libpurple/account.h
+++ b/libpurple/account.h
@@ -469,7 +469,7 @@ void purple_account_set_public_alias(Pur
*
* @param account The account
* @param success_cb A callback which will be called with the alias
- * @param failure_cb A callback which will be called if the prpl is
+ * @param failure_cb A callback which will be called if the protocol is
* unable to retrieve the server-side alias.
*/
void purple_account_get_public_alias(PurpleAccount *account,
@@ -586,7 +586,7 @@ void purple_account_set_ui_data(PurpleAc
*
* @return The UI data associated with this account. This is a
* convenience field provided to the UIs--it is not
- * used by the libuprple core.
+ * used by the libpurple core.
*/
gpointer purple_account_get_ui_data(const PurpleAccount *account);
@@ -1069,7 +1069,7 @@ void purple_account_destroy_log(PurpleAc
*
* @param account The account.
* @param buddy The buddy to add.
- * @param message The invite message. This may be ignored by a prpl.
+ * @param message The invite message. This may be ignored by a protocol.
*/
void purple_account_add_buddy(PurpleAccount *account, PurpleBuddy *buddy, const char *message);
@@ -1078,7 +1078,7 @@ void purple_account_add_buddy(PurpleAcco
*
* @param account The account.
* @param buddies The list of PurpleBlistNodes representing the buddies to add.
- * @param message The invite message. This may be ignored by a prpl.
+ * @param message The invite message. This may be ignored by a protocol.
*/
void purple_account_add_buddies(PurpleAccount *account, GList *buddies, const char *message);
diff --git a/libpurple/accounts.c b/libpurple/accounts.c
--- a/libpurple/accounts.c
+++ b/libpurple/accounts.c
@@ -104,10 +104,10 @@ static void
migrate_yahoo_japan(PurpleAccount *account)
{
/* detect a Yahoo! JAPAN account that existed prior to 2.6.0 and convert it
- * to use the new prpl-yahoojp. Also remove the account-specific settings
+ * to use the new yahoojp protocol. Also remove the account-specific settings
* we no longer need */
- if(purple_strequal(purple_account_get_protocol_id(account), "prpl-yahoo")) {
+ if(purple_strequal(purple_account_get_protocol_id(account), "yahoo")) {
if(purple_account_get_bool(account, "yahoojp", FALSE)) {
const char *serverjp = purple_account_get_string(account, "serverjp", NULL);
const char *xferjp_host = purple_account_get_string(account, "xferjp_host", NULL);
@@ -118,7 +118,7 @@ migrate_yahoo_japan(PurpleAccount *accou
purple_account_set_string(account, "server", serverjp);
purple_account_set_string(account, "xfer_host", xferjp_host);
- purple_account_set_protocol_id(account, "prpl-yahoojp");
+ purple_account_set_protocol_id(account, "yahoojp");
}
/* these should always be nuked */
@@ -136,7 +136,7 @@ migrate_icq_server(PurpleAccount *accoun
* 'mtn log --last 1 --no-graph --from b6d7712e90b68610df3bd2d8cbaf46d94c8b3794'
* for details on the change. */
- if(purple_strequal(purple_account_get_protocol_id(account), "prpl-icq")) {
+ if(purple_strequal(purple_account_get_protocol_id(account), "icq")) {
const char *tmp = purple_account_get_string(account, "server", NULL);
/* Non-secure server */
@@ -154,7 +154,7 @@ static void
migrate_xmpp_encryption(PurpleAccount *account)
{
/* When this is removed, nuke the "old_ssl" and "require_tls" settings */
- if (g_str_equal(purple_account_get_protocol_id(account), "prpl-jabber")) {
+ if (g_str_equal(purple_account_get_protocol_id(account), "jabber")) {
const char *sec = purple_account_get_string(account, "connection_security", "");
if (g_str_equal("", sec)) {
diff --git a/libpurple/blistnodetypes.h b/libpurple/blistnodetypes.h
--- a/libpurple/blistnodetypes.h
+++ b/libpurple/blistnodetypes.h
@@ -255,7 +255,7 @@ const char *purple_buddy_get_name(const
/**
* Returns a buddy's protocol-specific data.
*
- * This should only be called from the associated prpl.
+ * This should only be called from the associated protocol.
*
* @param buddy The buddy.
* @return The protocol data.
@@ -267,7 +267,7 @@ gpointer purple_buddy_get_protocol_data(
/**
* Sets a buddy's protocol-specific data.
*
- * This should only be called from the associated prpl.
+ * This should only be called from the associated protocol.
*
* @param buddy The buddy.
* @param data The data.
@@ -486,7 +486,7 @@ GType purple_chat_get_type(void);
*
* @param account The account this chat will get added to
* @param alias The alias of the new chat
- * @param components The info the prpl needs to join the chat. The
+ * @param components The info the protocol needs to join the chat. The
* hash function should be g_str_hash() and the
* equal function should be g_str_equal().
* @return A newly allocated chat
diff --git a/libpurple/buddyicon.h b/libpurple/buddyicon.h
--- a/libpurple/buddyicon.h
+++ b/libpurple/buddyicon.h
@@ -90,7 +90,7 @@ GType purple_buddy_icon_get_type(void);
* @param username The username the icon belongs to.
* @param icon_data The buddy icon data.
* @param icon_len The buddy icon length.
- * @param checksum A protocol checksum from the prpl or @c NULL.
+ * @param checksum A protocol checksum from the protocol or @c NULL.
*
* @return The buddy icon structure, with a reference for the caller.
*/
@@ -130,7 +130,7 @@ void purple_buddy_icon_update(PurpleBudd
* @param data The buddy icon data, which the buddy icon code
* takes ownership of and will free.
* @param len The length of the data in @a data.
- * @param checksum A protocol checksum from the prpl or @c NULL.
+ * @param checksum A protocol checksum from the protocol or @c NULL.
*/
void
purple_buddy_icon_set_data(PurpleBuddyIcon *icon, guchar *data,
@@ -157,7 +157,7 @@ const char *purple_buddy_icon_get_userna
/**
* Returns the buddy icon's checksum.
*
More information about the Commits
mailing list
diff --git a/libpurple/blistnodetypes.c b/libpurple/blistnodetypes.c
--- a/libpurple/blistnodetypes.c
+++ b/libpurple/blistnodetypes.c
@@ -57,7 +57,7 @@ struct _PurpleBuddyPrivate {
char *local_alias; /**< The user-set alias of the buddy */
char *server_alias; /**< The server-specified alias of the buddy.
(i.e. MSN "Friendly Names") */
- void *proto_data; /**< This allows the prpl to associate
+ void *proto_data; /**< This allows the protocol to associate
whatever data it wants with a buddy
TODO Remove this field. Protocols should
subclass PurpleBuddy and store
@@ -631,7 +631,7 @@ purple_buddy_dispose(GObject *object)
PurpleProtocol *protocol;
/*
* Tell the owner PRPL that we're about to free the buddy so it
* can free proto_data
*/
protocol = purple_protocols_find(purple_account_get_protocol_id(priv->account));
@@ -1455,7 +1455,7 @@ void purple_group_set_name(PurpleGroup *
/*
* TODO: This seems like a dumb way to do this... why not just
* append all children from the old group to the end of the new
- * one? PRPLs might be expecting to receive an add_buddy() for
+ * one? Protocols might be expecting to receive an add_buddy() for
* each moved buddy...
*/
while (child)
@@ -1510,7 +1510,7 @@ void purple_group_set_name(PurpleGroup *
if (ops && ops->update)
ops->update(purple_blist_get_buddy_list(), PURPLE_BLIST_NODE(source));
- /* Notify all PRPLs */
+ /* Notify all protocols */
/* TODO: Is this condition needed? Seems like it would always be TRUE */
if(old_name && !purple_strequal(priv->name, old_name)) {
for (accts = purple_group_get_accounts(source); accts; accts = g_slist_remove(accts, accts->data)) {
@@ -631,7 +631,7 @@ purple_buddy_dispose(GObject *object)
PurpleProtocol *protocol;
/*
- * Tell the owner PRPL that we're about to free the buddy so it
+ * Tell the owner protocol that we're about to free the buddy so it
* can free proto_data
*/